
capture log close


/*This do file creates the tables and figures in:

Abate, de Brauw, Hirvonen, and Wolle. "Measuring consumption over the phone: Evidence from a survey experiment in urban Ethiopia", published in the Journal of Development Economics.

*/

global user "`c(username)'"


*set globals for file paths:
global final_data "C:/Users/${user}/Dropbox (IFPRI)/research/FV RCT/in-person_phone experiment/replication_files/data" 
global results "C:/Users/${user}/Dropbox (IFPRI)/research/FV RCT/in-person_phone experiment/replication_files/results"
global logfile	"C:/Users/${user}/Dropbox (IFPRI)/research/FV RCT/in-person_phone experiment/replication_files/logfile"

*start logging:

log using "$logfile\Abate_et_al_JDE_Measuring_consumption_over_the_phone.log", replace

*Stata version:
version 17


use "$final_data/Abate_et_al_2022_JDE_Measuring_consumption_over_the_phone_Data.dta", clear
*unique identifier:
isid hh_uniq_id, sort
 

***********************************************************************************************************************************************
*Table 2. Household characteristics, by survey mode
***********************************************************************************************************************************************
global X female_respondent hhsize head_male head_educ asset_index n_interviews lntot_fexp_2019

*this table is constructed using a user-written package called ietoolkit:
ssc install ietoolkit, replace

iebaltab $X, grpvar(phone)  vce(cluster cluster) save("$results/Table_2_balance") replace  rowvarlabel pttest


************************************************************************************************************************************************
*Appendix Figure A1. Distribution of (ln) weekly food consumption per capita (in birr) in September-2019, by survey mode type
************************************************************************************************************************************************
twoway (kdensity lntot_fexp_2019 if phone==0, lcolor(maroon) lpattern(solid)) (kdensity lntot_fexp_2019 if phone==1, lcolor(black) lpattern(dash)), ytitle("Density", margin(medsmall)) xtitle("(log) Household per capita food consumption in September 2019", margin(medium)) legend(order(1 "In-person" 2 "Phone") region(lcolor(none)) position(1) ring(0)) scheme(s1color) ylabel(0(0.1)0.8) xlabel(3(1)9)
graph export "$results/Figure_A1_kernel_density_expenditure_2019.tif", replace width(1200)  

	count if lntot_fexp_2019!=.
 
************************************************************************************************************************************************
*Figure 1. Distribution of (ln) weekly total consumption per capita (in birr), by survey mode type
************************************************************************************************************************************************
	assert lntotcons_pc!=0
	sum lntotcons_pc, det
 
twoway (kdensity lntotcons_pc  if phone==0, lcolor(maroon) lpattern(solid)) (kdensity lntotcons_pc  if phone==1, lcolor(black) lpattern(dash)), ytitle("Density", margin(medsmall)) xtitle("(log) Household per capita consumption", margin(medium)) legend(order(1 "In-person" 2 "Phone") region(lcolor(none)) position(1) ring(0)) scheme(s1color)  ylabel(0(0.1)0.8) xlabel(4(1)9)  
graph export "$results/Figure_1_kernel_density_expenditure.tif", replace width(1200)  
count if lntotcons_pc!=.
 
**************************************************************************************************
*Table 3. Impact of phone survey mode on weekly per capita total consumption (in birr)
**************************************************************************************************

global CONTROLS  hhsize head_male head_educ i.sub_city
global phone phone

	*log expenditures:
	global Y  lntotcons_pc
	reg $Y $phone, cluster(cluster)
	estimates store r1
	
	*Exact interpretation:

	local coef1=_b[phone]
	local var1=(_se[phone])^2
	local lo =_b[phone] - invttail(e(df_r),0.025)*_se[phone]
	local hi = _b[phone] + invttail(e(df_r),0.025)*_se[phone]

	di `coef1'
	di `var1'
	di `lo'
	di `hi'

 	di (exp(`coef1'-0.5*`var1')-1)*100
	
	*Confidence intervals:
 	di (exp(`lo'-0.5*`var1')-1)*100
	di (exp(`hi'-0.5*`var1')-1)*100	

	*log expenditures + CONTROLS::
	global Y  lntotcons_pc
	reg $Y $phone $CONTROLS, cluster(cluster)
	estimates store r2

	*Exact interpretation:

	local coef1=_b[phone]
	local var1=(_se[phone])^2
	local lo =_b[phone] - invttail(e(df_r),0.025)*_se[phone]
	local hi = _b[phone] + invttail(e(df_r),0.025)*_se[phone]

	di `coef1'
	di `var1'
	di `lo'
	di `hi'

 	di (exp(`coef1'-0.5*`var1')-1)*100
	
	*Confidence intervals:
 	di (exp(`lo'-0.5*`var1')-1)*100
	di (exp(`hi'-0.5*`var1')-1)*100	 
	 

	*mean per capita amounts in control group:
	sum totcons_pc if $phone==0

	*non-logged expenditures:
	global Y  totcons_pc
	reg $Y $phone, cluster(cluster)
	estimates store r3

	*non-logged  expenditures + CONTROLS:
	global Y  totcons_pc
	reg $Y $phone $CONTROLS, cluster(cluster)
	estimates store r4
 
esttab r1 r2 r3 r4 using "$results/table_3_main_results.rtf", nogaps r2  se label star(* 0.10 ** 0.05 *** 0.01) title("Table 3. Impact of phone survey mode on household weekly per capita consumption") replace  b(%9.3f)   mtitles("log expenditures" "log expenditures adjusted" "expenditures" "expenditures adjusted") keep($phone)

**************************************************************************************************
*Table 4. Impact of phone survey mode on components of household consumption
**************************************************************************************************

	d exp_home_pc food_outsideYN fexp_outside_pc nonfood_exp_pc

	gen homefoodshare=100*exp_home_pc/totcons_pc
	bys $phone: sum homefoodshare

	reg homefoodshare $phone  $CONTROLS, cluster(cluster)

*a) Food consumption at home:	
	global Y lnexp_home_pc 
	reg $Y $phone  $CONTROLS, cluster(cluster)
	estimates store r1
	
	*Exact interpretation:

	local coef1=_b[phone]
	local var1=(_se[phone])^2
	local lo =_b[phone] - invttail(e(df_r),0.025)*_se[phone]
	local hi = _b[phone] + invttail(e(df_r),0.025)*_se[phone]

	di `coef1'
	di `var1'
	di `lo'
	di `hi'

 	di (exp(`coef1'-0.5*`var1')-1)*100
	
	*Confidence intervals:
 	di (exp(`lo'-0.5*`var1')-1)*100
	di (exp(`hi'-0.5*`var1')-1)*100	 

*b) Food consumption outside of home:	
	
	ta food_outsideYN
	global Y food_outsideYN 
	reg $Y $phone  $CONTROLS, cluster(cluster)
	estimates store r2


	global Y fexp_outside_pc 
	reg $Y $phone  $CONTROLS, cluster(cluster)
	estimates store r3

	sum fexp_outside_pc if $phone==0

*c) Non-food consumption:
	
	global Y lnnonfood_exp 
	reg $Y $phone  $CONTROLS, cluster(cluster)
	estimates store r4
	*Exact interpretation:

	local coef1=_b[phone]
	local var1=(_se[phone])^2
	local lo =_b[phone] - invttail(e(df_r),0.025)*_se[phone]
	local hi = _b[phone] + invttail(e(df_r),0.025)*_se[phone]

	di `coef1'
	di `var1'
	di `lo'
	di `hi'

 	di (exp(`coef1'-0.5*`var1')-1)*100
	
	*Confidence intervals:
 	di (exp(`lo'-0.5*`var1')-1)*100
	di (exp(`hi'-0.5*`var1')-1)*100	 


sum food_outsideYN  fexp_outside_pc if $phone==0

esttab r1 r2 r3 r4 using "$results/table_4_consumption_components.rtf", nogaps r2  se label star(* 0.10 ** 0.05 *** 0.01) title("Table 4. Impact of phone survey mode on components of household consumption") replace  b(%9.3f)   mtitles("ln food in home expenditures" "food outside home YN" "food outside home expenditures" "ln non-food expenditures") keep($phone)

**************************************************************************************************
*Table 5. Impact of phone survey mode on poverty rate
**************************************************************************************************
tab poor [fweight=hhsize] if $phone==0 
 
global Y poor

table $phone  [fweight=hhsize], stat(mean poor) notot

reg $Y $phone  [fweight=hhsize], cluster(cluster)
estimates store r1

reg $Y $phone  $CONTROLS  [fweight=hhsize], cluster(cluster)
estimates store r2

esttab r1 r2 using "$results/table_5_poverty.rtf", nogaps r2  se label star(* 0.10 ** 0.05 *** 0.01) title("Table 5. Impact of phone survey mode on poverty rate") replace  b(%9.3f)   mtitles("expenditures" " expenditures adjusted" "log expenditures" "log expenditures adjusted") keep($phone)


**********************************************************************************************************
*Table 6. Impact of phone survey mode on household dietary diversity indicators
**********************************************************************************************************
 
*Household Diet Diversity Score:
global Y HDDS
reg $Y $phone, cluster(cluster)
estimates store r1

reg $Y $phone  $CONTROLS, cluster(cluster)
estimates store r2


*WFP's Food Consumption Score:
global Y FCS_score
reg $Y $phone, cluster(cluster)
estimates store r3

reg $Y $phone  $CONTROLS, cluster(cluster)
estimates store r4
  
*Mean values in control group:
sum HDDS FCS_score   if $phone==0
  
esttab r1 r2 r3 r4    using "$results/table_6_HDDS_FCS.rtf", nogaps r2  se label star(* 0.10 ** 0.05 *** 0.01) title("Table 6. Impact of phone survey mode on household dietary diversity indicators")replace  b(%9.3f) mtitles("HDDS" "HDDS adjusted" "FCS" "FCS adjusted") keep($phone)

 
**************************************************************************************************
*Table 7. Impact of item's relative position in the questionnaire and phone survey mode on reported per capita food consumption value measured in birr
**************************************************************************************************
preserve

use "$final_data/Abate_et_al_2022_JDE_Measuring_consumption_over_the_phone_Item_level_data1.dta", clear
*unique identifiers:
isid hh_uniq_id food_item, sort
 
gen phoneXlater=phone*later

 
global Y fexp_pc
sum $Y
 
xtreg $Y phone later $CONTROLS, fe i (food_item) cluster(food_item)
estimates store r1
xtreg $Y phoneXlater phone later $CONTROLS, fe i (food_item) cluster(food_item)
estimates store r2
lincom _b[phoneXlater]+ _b[later]

sum $Y if phone==0
 
esttab r1 r2    using "$results/table_7_food_itemvalue.rtf", nogaps r2  se label star(* 0.10 ** 0.05 *** 0.01) title("Table 7. Impact of item's relative position in the questionnaire and phone survey mode on reported per capita food consumption value measured in birr") replace  b(%9.3f)  keep(later phone phoneXlater  ) order(later phone phoneXlater)
 
************************************************************************************************** 
*Appendix Table A3. Replicating Table 7, but using binary consumption variable as the dependent variable
************************************************************************************************** 
global Y fexpYN 
sum $Y

xtreg $Y phone later $CONTROLS, fe i (food_item) cluster(food_item)
estimates store r1
xtreg $Y phoneXlater phone later $CONTROLS, fe i (food_item) cluster(food_item)
estimates store r2

 sum $Y if phone==0

esttab   r1 r2 using "$results/table_A3_food_itemYN.rtf", nogaps r2  se label star(* 0.10 ** 0.05 *** 0.01) title("Table A3. Replicating Table 7, but using binary consumption variable as the dependent variable") replace  b(%9.3f)  keep(later phone phoneXlater  ) order(later phone phoneXlater)
  
 
restore  
 

**************************************************************************************************
*Table 8. Regression results from interaction models
**************************************************************************************************
gen head_educXphone=head_educ*phone
gen hhsizeXphone=hhsize*phone

 
*log food per capita expenditures:
global Y lnexp_pc
reg $Y $phone head_educXphone $CONTROLS, cluster(cluster)
estimates store r1

reg $Y $phone hhsizeXphone $CONTROLS, cluster(cluster)
estimates store r2
 
*log non-food per capita expenditures: 
global Y lnnonfood_exp
reg $Y $phone head_educXphone $CONTROLS, cluster(cluster)
estimates store r3

reg $Y $phone hhsizeXphone $CONTROLS, cluster(cluster)
estimates store r4

esttab r1 r2 r3 r4  using "$results/table_8_Heterogeneity.rtf", nogaps r2  se label star(* 0.10 ** 0.05 *** 0.01) title("Table 8. Regression results from interaction models")replace  b(%9.3f) mtitles("Food: head_educ" "Food: hh size" "Non-food: head_educ" "Non-food: hh size") keep($phone *Xphone)

 

**********************************************************************************************************
*Appendix Figure A2. Impact of phone survey method on household consumption of different food groups
**********************************************************************************************************

*We need this user-written package:
ssc install regsave, replace


*Value of consumption:

global Y fexp_staple
reg $Y $phone $CONTROLS, cluster(cluster)
regsave $phone using "$results/data_figure_a2", addlabel(id, 1)   replace  ci  level(95) 

global Y fexp_legum
reg $Y $phone $CONTROLS, cluster(cluster)
regsave $phone using "$results/data_figure_a2", addlabel(id, 2)   append  ci  level(95) 

global Y fexp_veg
reg $Y $phone $CONTROLS, cluster(cluster)
regsave $phone using "$results/data_figure_a2", addlabel(id, 3)   append  ci  level(95) 

global Y fexp_fruit
reg $Y $phone $CONTROLS, cluster(cluster)
regsave $phone using "$results/data_figure_a2", addlabel(id, 4)   append  ci  level(95) 

global Y fexp_meat
reg $Y $phone $CONTROLS, cluster(cluster)
regsave $phone using "$results/data_figure_a2", addlabel(id, 5)   append  ci  level(95) 

global Y fexp_dairy
reg $Y $phone $CONTROLS, cluster(cluster)
regsave $phone using "$results/data_figure_a2", addlabel(id, 6)   append  ci  level(95) 

global Y fexp_oth
reg $Y $phone $CONTROLS, cluster(cluster)
regsave $phone using "$results/data_figure_a2", addlabel(id, 7)   append  ci  level(95) 

  
*express these estimates directly as % of the mean value in the in-person group:

preserve
	sum fexp_staple fexp_legum fexp_veg fexp_fruit fexp_meat fexp_dairy fexp_oth if $phone==0, separator(0)
	keep if   $phone==0
	collapse (mean) fexp_staple fexp_legum fexp_veg fexp_fruit fexp_meat fexp_dairy fexp_oth
	xpose, clear
	ren v1 blval
	generate id = 1 in 1
	replace id = 2 in 2
	replace id = 3 in 3
	replace id = 4 in 4
	replace id = 5 in 5
	replace id = 6 in 6
	replace id = 7 in 7

	tempfile bl
	save `bl'
restore


use "$results/data_figure_a2.dta", clear
 
label define id 1 "{bf:Staples}" 2 "{bf:Legumes}" 3 "{bf:Vegetables}" 4 "{bf:Fruit}" 5 "{bf:Meat & eggs}" 6 "{bf:Dairy}" 7 "{bf:Other}", replace
label values id id
 
merge 1:1 id using `bl'
assert _m==3
drop _m
 
foreach v of varlist coef  ci_lower  ci_upper {
gen `v'2=100*`v'/blval
}
 twoway (scatter coef2  id, sort mcolor(navy) msymbol(smcircle)) (rcap ci_lower2  ci_upper2  id, sort lcolor(navy)), ytitle("Effect as % of in-person group mean", margin(medsmall)) yline(0, lpattern(dash) lcolor(black)) ylabel(-60(20)40, labels labsize(small) angle(ninety) valuelabel) yscale(alt) xtitle("") xlabel(1(1)7, labels angle(ninety) valuelabel) legend(off) scheme(s1color) plotregion(margin(10 10 5 5)) ymtick(-60(10)40, ticks grid gmin gmax)  
graph export "$results\Figure_A2.tif", width(900) replace


**********************************************************************************************************
*Appendix Figure A4. Robustness of leaving one enumerator out of the dataset at a time
**********************************************************************************************************

use "$final_data/Abate_et_al_2022_JDE_Measuring_consumption_over_the_phone_Data.dta", clear
isid hh_uniq_id, sort
 
 
	global CONTROLS  hhsize head_male head_educ i.sub_city
	global phone phone

 
	*Benchmark:
	global Y  lntotcons_pc
	reg $Y $phone $CONTROLS, cluster(cluster)
	regsave $phone using "$results/data_figure_a4", addlabel(id, 0)   replace  ci  level(95) 

	
	foreach v of numlist 1/21 {
	*this enumerator ID is dropped:
	ta enum_id if enum_id==`v'	
	reg $Y $phone $CONTROLS if enum_id!=`v'	, cluster(cluster)
	regsave $phone using "$results/data_figure_a4", addlabel(id, `v')   append  ci  level(95) 
	}	

use "$results/data_figure_a4.dta", clear
isid id
sum id
di  `r(max)'
assert `r(max)'==21

twoway (scatter coef id if id==0, mcolor(edkblue)) (rcap ci_upper ci_lower id if id==0, lcolor(edkblue))  (scatter coef id if id>0, sort mcolor(maroon) msymbol(circle_hollow)) (rcap ci_upper ci_lower id  if id>0,fcolor(maroon) lcolor(maroon)),  scheme(s1color) yline(0,lcolor(black)  lpattern(dash) extend) legend(order(1 "Benchmark estimate" 2 "95% CI" 3 "Subsample estimate" 4 "95% CI") row(2) position(12)) xtitle("ID of the omitted enumerator", margin(medium)) ytitle("Estimate",margin(small))  xlabel(1(1)21, labsize(small) )   ylabel(0.2(0.1)-0.6, format(%9.1f) labsize(small))  plotregion(margin(5 5 2 2))
graph export "$results\Figure_A4_dropping_one_enumerator_at_a_time.tif", width(900) replace
 
 
*************************************************************************************************************************************************************
*Appendix Table A5. Robustness to controlling for enumerator characteristics
*************************************************************************************************************************************************************
use "$final_data/Abate_et_al_2022_JDE_Measuring_consumption_over_the_phone_Data.dta", clear
isid hh_uniq_id, sort

ta phone

global CONTROLS  hhsize head_male head_educ   i.sub_city
global phone phone
global enum_chars enum_age enum_msc_dip enum_exp   

bys $phone: sum  $enum_chars
	
	*use log expenditures:
	global Y  lntotcons_pc
	
	reg $Y $phone $CONTROLS, cluster(cluster)
	estimates store r1
 
	reg $Y $phone $CONTROLS $enum_chars, cluster(cluster)
	estimates store r2
	 
	xtreg $Y $phone $CONTROLS, re i (enum_id) cluster(enum_id)
	estimates store r3

*Mundlak estimator:
	foreach v of varlist hhsize head_male head_educ   {
	bysort enum_id: egen mean_`v' = mean(`v')
	}
	xtreg $Y $phone $CONTROLS mean_*, re i (enum_id) cluster(enum_id)
	estimates store r4	
	

esttab r1 r2 r3 r4  using "$results/table_A5_enumerator_effects.rtf", nogaps r2  se label star(* 0.10 ** 0.05 *** 0.01) title("Table A5. Robustness to controlling for enumerator characteristics") replace  b(%9.3f)   mtitles("benchmark" "enumerator characteristics" "enumerator REs" "Mundlak enumerator REs") keep($phone)

  

*************************************************************************************************************************************************************
*Appendix : Benford's law analyses
*************************************************************************************************************************************************************

*in-person method:
	use "$final_data/Abate_et_al_2022_JDE_Measuring_consumption_over_the_phone_Item_level_data2.dta", clear
	*unique identifiers:
	isid hh_uniq_id food_item, sort

	*drop zeros:
	drop if quant_raw==0
	 
 
	 
*Appendix Figure A3. Predicted and observed first-digit distributions, by survey mode
*************************************************************************************************************************************************************
	
	*We need these user-written packages:
	ssc install digdis, replace
	ssc install moremata, replace
	ssc install mgof, replace
		
	digdis quant_raw, by(phone) percent  graph scheme(s1color)
	*graph style was then edited in Stata's Graph Editor
	graph export "$results/Figure_A3_benford.tif", replace width(1200)  

	keep if phone==0
 		
	digdis quant_raw, percent by(unit) generate(digs) notest nofreq 
	
	foreach v of numlist 1/9 {
	gen d`v'=digs==`v'
	}
	gen n=1
	
	*collapse to food item level
	collapse (sum) d? n, by(unit)

	egen all=rowtotal(d?)


	foreach v of numlist 1/9 {
	gen p`v'=100*d`v'/all
	}

	*expected percentages:
	gen	ben1=	30.103
	gen	ben2=	17.609
	gen	ben3=	12.494
	gen	ben4=	9.691
	gen	ben5=	7.918
	gen	ben6=	6.695
	gen	ben7=	5.799
	gen	ben8=	5.115
	gen	ben9=	4.576

	*calculate euclidean distance:

	gen dist = (p1-ben1)^2 + (p2-ben2)^2 + (p3-ben3)^2 + (p4-ben4)^2 + (p5-ben5)^2 + (p6-ben6)^2 + (p7-ben7)^2 + (p8-ben8)^2 + (p9-ben9)^2
	replace dist=sqrt(dist)
	keep dist unit  n
	gen phone=0
	tempfile temp
	save `temp'

	*telephone method:
	use "$final_data/Abate_et_al_2022_JDE_Measuring_consumption_over_the_phone_Item_level_data2.dta", clear
	keep if phone==1
	drop if quant_raw==0

	digdis quant_raw, percent by(unit) generate(digs) notest nofreq

	foreach v of numlist 1/9 {
	gen d`v'=digs==`v'
	}
	gen n=1
	collapse (sum) d? n, by(unit)

	egen all=rowtotal(d?)


	foreach v of numlist 1/9 {
	gen p`v'=100*d`v'/all
	}

	*expected percentages:
	gen	ben1=	30.103
	gen	ben2=	17.609
	gen	ben3=	12.494
	gen	ben4=	9.691
	gen	ben5=	7.918
	gen	ben6=	6.695
	gen	ben7=	5.799
	gen	ben8=	5.115
	gen	ben9=	4.576

	*calculate euclidean distance:

	gen dist = (p1-ben1)^2 + (p2-ben2)^2 + (p3-ben3)^2 + (p4-ben4)^2 + (p5-ben5)^2 + (p6-ben6)^2 + (p7-ben7)^2 + (p8-ben8)^2 + (p9-ben9)^2
	replace dist=sqrt(dist)
 
	keep dist unit n
	gen phone=1
	 
	append using  `temp'

	duplicates tag unit, gen(tag)
	tab tag
	*drop items that do not appear for both groups:
	keep if tag==1
	
	unique unit
	 *33 different units
	sum dist
	gen ndist=(dist-r(mean))/r(sd) 

*Appendix Table A4. Testing differences in Euclidean distance to the distribution predicted by Benford's law
*************************************************************************************************************************************************************	
 	reg ndist phone, cluster(unit)  
	estimates store r1

 	xtreg ndist phone, fe i (unit)  cluster(unit) 
	estimates store r2
 	
esttab r1 r2  using "$results/table_A4_benfords_law_test.rtf", nogaps r2  se label star(* 0.10 ** 0.05 *** 0.01) title("Table A4. Testing differences in Euclidean distance to the distribution predicted by Benford's law")replace  b(%9.3f)  keep(phone)

*the end:

*these files are not needed:
erase "$results/data_figure_a2.dta"
erase "$results/data_figure_a4.dta"

clear

log close
